@@ -3,10 +3,12 @@ package POE::Exceptions;
 use strict;
 use warnings;
 
-use POE::Kernel::Exception;
 use POE::Session::Exception;
 
-our $VERSION = '2.'.sprintf "%04d", (qw($Rev: 528 $))[1];
+our $VERSION = '2.'.sprintf "%04d", (qw($Rev: 1 $))[1];
+
+1;
+__END__
 
 =head1 NAME
 
@@ -30,9 +32,11 @@ POE::Exceptions - POE class for handling exceptions
 
     $poe_kernel->run();
 
-=head1 AUTHOR
+=head1 DEPRECATION
 
-Matt Cashner (sungo@pobox.com)
+This module is deprecated as its functionality has been rolled into
+the POE core, as of POE 0.33. This module will receive no updates
+and will be removed from CPAN at some point in the near future.
 
 =head1 DISCUSSION
 
@@ -50,6 +54,20 @@ B<Caveat:> POE::Exceptions will die on its own in the case of a double
 exception fault. If the C<DIE> signal handler itself throws an
 exception, POE::Exceptions will shut the program down and bail out.
 
+=head1 DATE
+
+$Date: 2006-03-19 10:01:04 -0500 (Sun, 19 Mar 2006) $
+
+=head1 REVISION
+
+$Revision: 1 $
+
+=head1 AUTHOR
+
+Matt Cashner (sungo@pobox.com)
+
+See L<http://perlwhore.com> for the latest on all of sungo's modules.
+
 =head1 LICENSE
 
 Copyright (c) 2002-2005, Matt Cashner. All rights reserved.
@@ -82,4 +100,4 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 =cut
 
-1;
+# sungo // vim: ts=4 sw=4 et
